@@ -54,6 +54,7 @@ BANANA_PI_M2_ZERO = "BANANA_PI_M2_ZERO"
 # NVIDIA Jetson boards
 JETSON_TX1 = "JETSON_TX1"
 JETSON_TX2 = "JETSON_TX2"
+JETSON_TX2_NX = "JETSON_TX2_NX"
 CLARA_AGX_XAVIER = "CLARA_AGX_XAVIER"
 JETSON_XAVIER = "JETSON_XAVIER"
 JETSON_NANO = "JETSON_NANO"
@@ -69,6 +70,7 @@ PYNQ_Z2 = "PYNQ_Z2"
 
 # STM32 MPU boards
 STM32MP157C_DK2 = "STM32MP157C_DK2"
+OSD32MP1_BRK = "OSD32MP1_BRK"
 
 # Embedfire LubanCat board
 LUBANCAT_IMX6ULL = "LUBANCAT_IMX6ULL"
@@ -120,6 +122,7 @@ PINEPHONE = "PINEPHONE"
 SOPINE = "SOPINE"
 
 ROCK_PI_S = "ROCK_PI_S"
+ROCK_PI_4 = "ROCK_PI_4"
 ROCK_PI_X = "ROCK_PI_X"
 
 GREATFET_ONE = "GREATFET_ONE"
@@ -136,6 +139,7 @@ _ASUS_TINKER_BOARD_IDS = (ASUS_TINKER_BOARD,)
 _STM32MP1_IDS = (
     STM32MP157C_DK2,
     LUBANCAT_STM32MP157,
+    OSD32MP1_BRK,
 )
 
 # OrangePI
@@ -195,6 +199,7 @@ _JETSON_IDS = (
             "nvidia,storm",
         ),
     ),
+    (JETSON_TX2_NX, ("nvidia,p3509-0000+p3636-0001",)),
     (CLARA_AGX_XAVIER, ("nvidia,e3900-0000+p2888-0004",)),
     (
         JETSON_XAVIER,
@@ -337,6 +342,7 @@ _PI_REV_CODES = {
         "1000003",
     ),
     RASPBERRY_PI_B_REV2: (
+        "0004",
         "0005",
         "0006",
         "000d",
@@ -442,6 +448,7 @@ _PI_REV_CODES = {
     RASPBERRY_PI_CM4: (
         "a03140",
         "b03140",
+        "c03140",
     ),
 }
 
@@ -451,5 +458,8 @@ _ONION_OMEGA_BOARD_IDS = (ONION_OMEGA, ONION_OMEGA2)
 # Pine64 boards and devices
 _PINE64_DEV_IDS = (PINE64, PINEH64, PINEBOOK, PINEPHONE, SOPINE)
 
+# RockPi boards and devices
+_ROCK_PI_IDS = (ROCK_PI_S, ROCK_PI_4, ROCK_PI_X)
+
 # UDOO
 _UDOO_BOARD_IDS = {UDOO_BOLT_V8: ("SC40-2000-0000-C0|C",), UDOO_X86: ("dummy",)}
